module fixpkt(reset, clk,
	   	in_ready, in_valid, in_eop, in_sop, in_data,
		out_ready, out_valid, out_eop, out_sop, out_data);
	parameter width = 20;
	parameter height = 30;
	parameter interlacing = 0;
	parameter BPP = 10;

	input reset, clk;

	input [BPP-1:0] in_data;
	output [BPP-1:0] out_data;

	output in_ready, out_valid, out_eop, out_sop;
	input in_valid, out_ready, in_eop, in_sop;

	wire reset;
	wire clk;

	reg in_ready;
   	wire in_valid;
	wire in_eop;
   	wire in_sop;
	wire [BPP-1:0] in_data;

	wire out_ready;
	reg out_valid;
	reg out_eop;
   	reg out_sop;
	reg [BPP-1:0] out_data;
	
	reg [3:0] state;
	reg [BPP-1:0] first_symbol;

	always @* begin
		case (state)
			// initial state
			0: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 0; out_data = 0; end
			// wait for the first symbol
			1: begin in_ready = 1; out_sop = 0; out_eop = 0; out_valid = 0; out_data = 0; end
			// start sending the control packet
			2: begin in_ready = 0; out_sop = 1; out_eop = 0; out_valid = 1; out_data = 'd15; end
			3: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = width[15:12]; end
			4: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = width[11:8]; end
			5: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = width[7:4]; end
			6: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = width[3:0]; end
			7: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = height[15:12]; end
			8: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = height[11:8]; end
			9: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = height[7:4]; end
			10: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = height[3:0]; end
			11: begin in_ready = 0; out_sop = 0; out_eop = 1; out_valid = 1; out_data = interlacing[3:0]; end
			// start sending the data packet
			12: begin in_ready = 0; out_sop = 1; out_eop = 0; out_valid = 1; out_data = 'd0; end
			// send the stored first symbol
			13: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 1; out_data = first_symbol; end
			// pass throught the rest of data
			14: begin in_ready = out_ready; out_sop = 0; out_eop = in_eop; out_valid = in_valid; out_data = in_data; end
			default: begin in_ready = 0; out_sop = 0; out_eop = 0; out_valid = 0; out_data = 0; end
		endcase
	end

	always @(posedge clk) begin
		if (reset) begin
			state <= 0;
			first_symbol <= 0;
		end else begin
			case(state)
				0:  state <= 1;
				1:  if (in_valid && in_sop) begin
						first_symbol <= in_data;
						state <= 2;
					end
				2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13: begin
						if (out_ready) state <= state + 1;
					end
				14: if (out_valid && out_eop && out_ready) begin
						state <= 1;
					end
				default:
					state <= 0;
			endcase
		end
	end

endmodule
